@@ -48,7 +48,7 @@
 namespace Oxygen
 {
 
-    //! stores engines
+    //* stores engines
     class Animations: public QObject
     {
 
@@ -56,151 +56,155 @@ namespace Oxygen
 
         public:
 
-        //! constructor
+        //* constructor
         explicit Animations( QObject* );
 
-        //! destructor
-        virtual ~Animations( void )
-        {}
-
-        //! register animations corresponding to given widget, depending on its type.
+        //* register animations corresponding to given widget, depending on its type.
         void registerWidget( QWidget* widget ) const;
 
-        /*! unregister all animations associated to a widget */
+        /** unregister all animations associated to a widget */
         void unregisterWidget( QWidget* widget ) const;
 
-        //! enability engine
-        WidgetStateEngine& widgetEnabilityEngine( void ) const
-        { return *_widgetEnabilityEngine; }
+        //* enable state engine
+        WidgetStateEngine& widgetEnableStateEngine( void ) const
+        { return *_widgetEnableStateEngine; }
 
-        //! abstractButton engine
+        //* abstractButton engine
         WidgetStateEngine& widgetStateEngine( void ) const
         { return *_widgetStateEngine; }
 
-        //! editable combobox arrow hover engine
+        //* editable combobox arrow hover engine
         WidgetStateEngine& comboBoxEngine( void ) const
         { return *_comboBoxEngine; }
 
-        //! Tool buttons arrow hover engine
+        //* Tool buttons arrow hover engine
         WidgetStateEngine& toolButtonEngine( void ) const
         { return *_toolButtonEngine; }
 
-        //! splitter engine
+        //* item view engine
+        WidgetStateEngine& inputWidgetEngine( void ) const
+        { return *_inputWidgetEngine; }
+
+        //* splitter engine
         SplitterEngine& splitterEngine( void ) const
         { return *_splitterEngine; }
 
-        //! busy indicator
+        //* busy indicator
         BusyIndicatorEngine& busyIndicatorEngine( void ) const
         { return *_busyIndicatorEngine; }
 
-        //! dock separators engine
+        //* dock separators engine
         DockSeparatorEngine& dockSeparatorEngine( void ) const
         { return *_dockSeparatorEngine; }
 
-        //! header view engine
+        //* header view engine
         HeaderViewEngine& headerViewEngine( void ) const
         { return *_headerViewEngine; }
 
-        //! progressbar engine
+        //* progressbar engine
         ProgressBarEngine& progressBarEngine( void ) const
         { return *_progressBarEngine; }
 
-        //! menubar engine
+        //* menubar engine
         MenuBarBaseEngine& menuBarEngine( void ) const
         { return *_menuBarEngine; }
 
-        //! menu engine
+        //* menu engine
         MenuBaseEngine& menuEngine( void ) const
         { return *_menuEngine; }
 
-        //! scrollbar engine
+        //* scrollbar engine
         ScrollBarEngine& scrollBarEngine( void ) const
         { return *_scrollBarEngine; }
 
-        //! spinbox engine
+        //* spinbox engine
         SpinBoxEngine& spinBoxEngine( void ) const
         { return *_spinBoxEngine; }
 
-        //! tabbar
+        //* tabbar
         TabBarEngine& tabBarEngine( void ) const
         { return *_tabBarEngine; }
 
-        //! toolbar
+        //* toolbar
         ToolBarEngine& toolBarEngine( void ) const
         { return *_toolBarEngine; }
 
-        //! toolbox
+        //* toolbox
         ToolBoxEngine& toolBoxEngine( void ) const
         { return *_toolBoxEngine; }
 
-        //! mdi windows
+        //* mdi windows
         MdiWindowEngine& mdiWindowEngine( void ) const
         { return *_mdiWindowEngine; }
 
-        //! setup engines
+        //* setup engines
         void setupEngines( void );
 
-        protected Q_SLOTS:
+        private Q_SLOTS:
 
-        //! enregister engine
+        //* enregister engine
         void unregisterEngine( QObject* );
+
         private:
 
-        //! register new engine
+        //* register new engine
         void registerEngine( BaseEngine* engine );
 
-        //! busy indicator
-        BusyIndicatorEngine* _busyIndicatorEngine;
+        //* busy indicator
+        BusyIndicatorEngine* _busyIndicatorEngine = nullptr;
 
-        //! dock separator handle hover effect
-        DockSeparatorEngine* _dockSeparatorEngine;
+        //* dock separator handle hover effect
+        DockSeparatorEngine* _dockSeparatorEngine = nullptr;
 
-        //! headerview hover effect
-        HeaderViewEngine* _headerViewEngine;
+        //* headerview hover effect
+        HeaderViewEngine* _headerViewEngine = nullptr;
 
-        //! widget enability engine
-        WidgetStateEngine* _widgetEnabilityEngine;
+        //* widget enable state engine
+        WidgetStateEngine* _widgetEnableStateEngine = nullptr;
 
-        //! abstract button engine
-        WidgetStateEngine* _widgetStateEngine;
+        //* abstract button engine
+        WidgetStateEngine* _widgetStateEngine = nullptr;
 
-        //! editable combobox arrow hover effect
-        WidgetStateEngine* _comboBoxEngine;
+        //* editable combobox arrow hover effect
+        WidgetStateEngine* _comboBoxEngine = nullptr;
 
-        //! mennu toolbutton arrow hover effect
-        WidgetStateEngine* _toolButtonEngine;
+        //* mennu toolbutton arrow hover effect
+        WidgetStateEngine* _toolButtonEngine = nullptr;
 
-        //! QSplitter engine
-        SplitterEngine* _splitterEngine;
+        //* item view engine
+        WidgetStateEngine* _inputWidgetEngine = nullptr;
 
-        //! progressbar engine
-        ProgressBarEngine* _progressBarEngine;
+        //* QSplitter engine
+        SplitterEngine* _splitterEngine = nullptr;
 
-        //! menubar engine
-        MenuBarBaseEngine* _menuBarEngine;
+        //* progressbar engine
+        ProgressBarEngine* _progressBarEngine = nullptr;
 
-        //! menu engine
-        MenuBaseEngine* _menuEngine;
+        //* menubar engine
+        MenuBarBaseEngine* _menuBarEngine = nullptr;
 
-        //! scrollbar engine
-        ScrollBarEngine* _scrollBarEngine;
+        //* menu engine
+        MenuBaseEngine* _menuEngine = nullptr;
 
-        //! spinbox engine
-        SpinBoxEngine* _spinBoxEngine;
+        //* scrollbar engine
+        ScrollBarEngine* _scrollBarEngine = nullptr;
 
-        //! tabbar engine
-        TabBarEngine* _tabBarEngine;
+        //* spinbox engine
+        SpinBoxEngine* _spinBoxEngine = nullptr;
 
-        //! toolbar engine
-        ToolBarEngine* _toolBarEngine;
+        //* tabbar engine
+        TabBarEngine* _tabBarEngine = nullptr;
 
-        //! toolbar engine
-        ToolBoxEngine* _toolBoxEngine;
+        //* toolbar engine
+        ToolBarEngine* _toolBarEngine = nullptr;
 
-        //! mdi window
-        MdiWindowEngine* _mdiWindowEngine;
+        //* toolbar engine
+        ToolBoxEngine* _toolBoxEngine = nullptr;
 
-        //! keep list of existing engines
+        //* mdi window
+        MdiWindowEngine* _mdiWindowEngine = nullptr;
+
+        //* keep list of existing engines
         QList< BaseEngine::Pointer > _engines;
 
     };
