@@ -36,7 +36,7 @@
 namespace Oxygen
 {
 
-    //! print widget's and parent's information on mouse click
+    //* print widget's and parent's information on mouse click
     class WidgetExplorer: public QObject
     {
 
@@ -44,39 +44,37 @@ namespace Oxygen
 
         public:
 
-        //! constructor
+        //* constructor
         explicit WidgetExplorer( QObject* );
 
-        //! enable
+        //* enable
         bool enabled( void ) const;
 
-        //! enable
+        //* enable
         void setEnabled( bool );
 
-        //! widget rects
+        //* widget rects
         void setDrawWidgetRects( bool value )
         { _drawWidgetRects = value; }
 
-        //! event filter
-        bool eventFilter( QObject*, QEvent* ) ;
-
-        protected:
-
-        //! event type
-        QString eventType( const QEvent::Type& ) const;
-
-        //! print widget information
-        QString widgetInformation( const QWidget* ) const;
+        //* event filter
+        bool eventFilter( QObject*, QEvent* ) override;
 
         private:
 
-        //! enable state
-        bool _enabled;
+        //* event type
+        QString eventType( const QEvent::Type& ) const;
 
-        //! widget rects
-        bool _drawWidgetRects;
+        //* print widget information
+        QString widgetInformation( const QWidget* ) const;
 
-        //! map event types to string
+        //* enable state
+        bool _enabled = false;
+
+        //* widget rects
+        bool _drawWidgetRects = false;
+
+        //* map event types to string
         QMap<QEvent::Type, QString > _eventTypes;
 
     };
