@@ -2,7 +2,8 @@
 #define oxygen_helper_h
 
 /*
- * Copyright 2009-2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+ * Copyright 2016 Michael Pyne <mpyne@kde.org>
+ * Copyright 2009 Hugo Pereira Da Costa <hugo.pereira@free.fr>
  * Copyright 2008 Long Huynh Huu <long.upcase@googlemail.com>
  * Copyright 2007 Matthew Woehlke <mw_triad@users.sourceforge.net>
  * Copyright 2007 Casper Boemann <cbr@boemann.dk>
@@ -39,6 +40,7 @@
 #include <QCache>
 #include <QColor>
 #include <QPixmap>
+#include <QQueue>
 #include <QWidget>
 #include <QPainterPath>
 #include <QScopedPointer>
@@ -106,6 +108,70 @@ namespace Oxygen
 
     };
 
+    /**
+     * Holds up to a limited number of items keyed by quint64. If items must be
+     * removed to fall within limit, removes those added the earliest.
+     */
+    template<typename T>
+    class FIFOCache
+    {
+        using CachePair = QPair<quint64, T>;
+
+        public:
+
+        //* constructor
+        FIFOCache(size_t _limit = 256) : m_limit(_limit)
+        {}
+
+        //* insert
+        void insert(quint64 key, T value)
+        {
+            if (static_cast<size_t>(m_queue.size()) > m_limit)
+            { (void) m_queue.dequeue(); }
+            m_queue.enqueue( CachePair( key, value) );
+        }
+
+        //* find
+        T find(quint64 key) const
+        {
+            for(const auto &item : m_queue)
+            { if (item.first == key) return item.second; }
+            return T();
+        }
+
+        //* for_each
+        template<typename F>
+        void for_each(F f)
+        {
+            for(auto &item : m_queue)
+            { f(item.second); }
+        }
+
+        //* maxCost
+        void setMaxCost( size_t max )
+        {
+            m_limit = max;
+            while (static_cast<size_t>(m_queue.size()) > m_limit)
+            { (void) m_queue.dequeue(); }
+        }
+
+        //* maxCost
+        size_t maxCost() const
+        { return m_limit; }
+
+        //* clear
+        void clear()
+        { m_queue.clear(); }
+
+        private:
+
+        //* queue
+        QQueue<CachePair> m_queue;
+
+        //* max size
+        size_t m_limit;
+    };
+
     template<typename T> class Cache
     {
 
@@ -119,21 +185,21 @@ namespace Oxygen
         ~Cache()
         {}
 
+        using Value = QSharedPointer<BaseCache<T>>;
+
         //* return cache matching a given key
-        //typedef QCache<quint64, T> Value;
-        typedef BaseCache<T> Value;
-        Value* get( const QColor& color )
+        Value get( const QColor& color )
         {
             const quint64 key = ( color.isValid() ? color.rgba():0 );
-            Value* cache = data_.object( key );
 
-            if ( !cache )
+            Value retValue = data_.find( key );
+            if ( !retValue )
             {
-                cache = new Value( data_.maxCost() );
-                data_.insert( key, cache );
+                retValue = Value( new BaseCache<T>( data_.maxCost() ) );
+                data_.insert( key, retValue );
             }
 
-            return cache;
+            return retValue;
         }
 
         //* clear
@@ -144,14 +210,13 @@ namespace Oxygen
         void setMaxCacheSize( int value )
         {
             data_.setMaxCost( value );
-            foreach( quint64 key, data_.keys() )
-            { data_.object( key )->setMaxCost( value ); }
+            data_.for_each( [value] (Value item) { item->setMaxCost( value );} );
         }
 
         private:
 
         //* data
-        BaseCache<Value> data_;
+        FIFOCache<Value> data_;
 
     };
 
@@ -227,33 +292,33 @@ namespace Oxygen
         static QColor alphaColor( QColor color, qreal alpha );
 
         //* calculated light color from argument
-        virtual const QColor& calcLightColor( const QColor& color );
+        virtual QColor calcLightColor( const QColor& color );
 
         //* calculated dark color from argument
-        virtual const QColor& calcDarkColor( const QColor& color );
+        virtual QColor calcDarkColor( const QColor& color );
 
         //* calculated shadow color from argument
-        virtual const QColor& calcShadowColor( const QColor& color );
+        virtual QColor calcShadowColor( const QColor& color );
 
         //* returns menu background color matching position in a given top level widget
-        virtual const QColor& backgroundColor( const QColor& color, const QWidget* w, const QPoint& point )
+        virtual QColor backgroundColor( const QColor& color, const QWidget* w, const QPoint& point )
         {
             if( !( w && w->window() ) || checkAutoFillBackground( w ) ) return color;
             else return backgroundColor( color, w->window()->height(), w->mapTo( w->window(), point ).y() );
         }
 
         //* returns menu background color matching position in a top level widget of given height
-        virtual const QColor& backgroundColor( const QColor& color, int height, int y )
+        virtual QColor backgroundColor( const QColor& color, int height, int y )
         { return backgroundColor( color, qMin( qreal( 1.0 ), qreal( y )/qMin( 300, 3*height/4 ) ) ); }
 
         //* color used for background radial gradient
-        virtual const QColor& backgroundRadialColor( const QColor& color );
+        virtual QColor backgroundRadialColor( const QColor& color );
 
         //* color used at the top of window background
-        virtual const QColor& backgroundTopColor( const QColor& color );
+        virtual QColor backgroundTopColor( const QColor& color );
 
         //* color used at the bottom of window background
-        virtual const QColor& backgroundBottomColor( const QColor& color );
+        virtual QColor backgroundBottomColor( const QColor& color );
 
         //* vertical gradient for window background
         virtual QPixmap verticalGradient( const QColor& color, int height, int offset = 0 );
@@ -262,7 +327,7 @@ namespace Oxygen
         virtual QPixmap radialGradient( const QColor& color, int width, int height = 20 );
 
         //* merge background and front color for check marks, arrows, etc. using _contrast
-        virtual const QColor& decoColor( const QColor& background, const QColor& color );
+        virtual QColor decoColor( const QColor& background, const QColor& color );
 
         //* returns a region matching given rect, with rounded corners, based on the multipliers
         /** setting any of the multipliers to zero will result in no corners shown on the corresponding side */
@@ -286,26 +351,6 @@ namespace Oxygen
         //* draw dividing line
         virtual void drawSeparator( QPainter*, const QRect&, const QColor&, Qt::Orientation );
 
-        //* default slab
-        virtual TileSet* slab( const QColor& color, qreal shade, int size = TileSet::DefaultSize )
-        { return slab( color, QColor(), shade, size );  }
-
-        //* default slab (with glow)
-        virtual TileSet* slab( const QColor&, const QColor& glow, qreal shade, int size = TileSet::DefaultSize );
-
-        //* sunken slab
-        virtual TileSet *slabSunken( const QColor&, int size = TileSet::DefaultSize );
-
-        //* fill a slab of given size with brush set on painter
-        void fillSlab( QPainter&, const QRect&, int size = TileSet::DefaultSize ) const;
-
-        //* linear gradient used to fill buttons
-        virtual void fillButtonSlab( QPainter&, const QRect&, const QColor&, bool sunken );
-
-        //* inverse (inner-hole) shadow
-        /** this method must be public because it is used directly by OxygenStyle to draw dials */
-        void drawInverseShadow( QPainter&, const QColor&, int pad, int size, qreal fuzz ) const;
-
         //* focus color
         QColor focusColor( const QPalette& palette ) const
         { return _viewFocusBrush.brush( palette ).color(); }
@@ -397,9 +442,6 @@ namespace Oxygen
         quint64 colorKey( const QColor& color ) const
         { return color.isValid() ? color.rgba():0; }
 
-        //* generic slab painting (to be stored in tilesets)
-        virtual void drawSlab( QPainter&, const QColor&, qreal shade );
-
         //* generic outer shadow (to be stored in tilesets)
         virtual void drawShadow( QPainter&, const QColor&, int size );
 
@@ -407,7 +449,7 @@ namespace Oxygen
         virtual void drawOuterGlow( QPainter&, const QColor&, int size );
 
         //* return background adjusted color matching relative vertical position in window
-        const QColor& backgroundColor( const QColor&, qreal ratio );
+        QColor backgroundColor( const QColor&, qreal ratio );
 
         //*@name global configuration parameters
         //@{
@@ -421,10 +463,10 @@ namespace Oxygen
 
         //* shortcut to color caches
         /** it is made protected because it is also used in the style helper */
-        typedef BaseCache<QColor> ColorCache;
+        using ColorCache = BaseCache<QColor>;
 
         //* shortcut to pixmap cache
-        typedef BaseCache<QPixmap> PixmapCache;
+        using PixmapCache = BaseCache<QPixmap>;
 
         private:
 
@@ -440,17 +482,6 @@ namespace Oxygen
         KSharedConfig::Ptr _config;
         qreal _bgcontrast;
 
-        //*@name tileset caches
-        //*@{
-
-        //* slabs
-        Oxygen::Cache<TileSet> _slabCache;
-
-        //* sunken slabs
-        BaseCache<TileSet> _slabSunkenCache;
-
-        //@}
-
         //*@name brushes
         //@{
         KStatefulBrush _viewFocusBrush;
@@ -474,7 +505,7 @@ namespace Oxygen
         PixmapCache _dotCache;
 
         //* high threshold colors
-        typedef QMap<quint32, bool> ColorMap;
+        using ColorMap = QMap<quint32, bool>;
         ColorMap _highThreshold;
         ColorMap _lowThreshold;
 
